@@ -87,8 +87,6 @@ struct _GladeWindowPrivate
 	GladeDesignView     *active_view;
 	gint                 num_tabs;
 	
-	GtkTooltips         *tooltips;
-
 	GtkWidget           *inspectors_notebook;
 
 	GtkWidget           *statusbar;                     /* A pointer to the status bar. */
@@ -667,6 +665,7 @@ project_selection_changed_cb (GladeProject *project, GladeWindow *window)
 		
 			glade_widget = glade_widget_get_from_gobject (G_OBJECT (list->data));
 			
+			/* translators: referring to the properties of a widget named '%s [%s]' */
 			text = g_strdup_printf (_("%s [%s] - Properties"),
 						glade_widget_get_name (glade_widget),
 						G_OBJECT_TYPE_NAME (glade_widget->object));
@@ -711,20 +710,25 @@ format_project_list_item_tooltip (GladeProject *project)
 		
 		if (glade_project_get_readonly (project))
 		{
-			tooltip = g_strdup_printf ("Activate '%s' %s",
+                        /* translators: referring to the action of activating a file named '%s'.
+                         *              we also indicate to users that the file may be read-only with
+                         *              the second '%s' */
+			tooltip = g_strdup_printf (_("Activate '%s' %s"),
 					   	   path,
 					   	   READONLY_INDICATOR);
 		}
 		else
 		{
-			tooltip = g_strdup_printf ("Activate '%s'", path);		
+                       /* translators: referring to the action of activating a file named '%s' */
+			tooltip = g_strdup_printf (_("Activate '%s'"), path);
 		}
 		g_free (path);
 	}
 	else
 	{
 		name = glade_project_get_name (project);
-		tooltip = g_strdup_printf ("Activate '%s'", name);
+                 /* FIXME add hint for translators */
+		tooltip = g_strdup_printf (_("Activate '%s'"), name);
 		g_free (name);
 	}
 	
@@ -1079,10 +1083,10 @@ refresh_projects_list_menu (GladeWindow *window)
 		GtkWidget *view;
 		GladeProject *project;
 		GtkRadioAction *action;
-		gchar *action_name;
+		gchar action_name[32];
 		gchar *project_name;
 		gchar *tooltip;
-		gchar *accel;
+		gchar accel[7];
 
 		view = gtk_notebook_get_nth_page (GTK_NOTEBOOK (p->notebook), i);
 		project = glade_design_view_get_project (GLADE_DESIGN_VIEW (view));
@@ -1095,17 +1099,18 @@ refresh_projects_list_menu (GladeWindow *window)
 		 * the problem is worked around, action with the same name always
 		 * get the same accel.
 		 */
-		action_name = g_strdup_printf ("Tab_%d", i);
+                g_snprintf (action_name, sizeof (action_name), "Tab_%d", i);
 		project_name = get_formatted_project_name_for_display (project,
 								       FORMAT_NAME_MARK_UNSAVED |
 								       FORMAT_NAME_MIDDLE_TRUNCATE |
 								       FORMAT_NAME_ESCAPE_UNDERSCORES);				       
 		tooltip = format_project_list_item_tooltip (project);
-		
-
 
 		/* alt + 1, 2, 3... 0 to switch to the first ten tabs */
-		accel = (i < 10) ? g_strdup_printf ("<alt>%d", (i + 1) % 10) : NULL;
+                if (i < 10)
+                        g_snprintf (accel, sizeof (accel), "<alt>%d", (i + 1) % 10);
+                else
+                        accel[0] = '\0';
 
 		action = gtk_radio_action_new (action_name, 
 					       project_name,
@@ -1117,10 +1122,8 @@ refresh_projects_list_menu (GladeWindow *window)
 		g_object_set_data (G_OBJECT (project), "project-list-action", action);
 		g_object_set_data (G_OBJECT (action), "project", project);
 
-		if (group != NULL)
-			gtk_radio_action_set_group (action, group);
-
 		/* note that group changes each time we add an action, so it must be updated */
+		gtk_radio_action_set_group (action, group);
 		group = gtk_radio_action_get_group (action);
 
 		gtk_action_group_add_action_with_accel (p->projects_list_menu_actions,
@@ -1142,10 +1145,8 @@ refresh_projects_list_menu (GladeWindow *window)
 
 		g_object_unref (action);
 
-		g_free (action_name);
 		g_free (project_name);
 		g_free (tooltip);
-		g_free (accel);
 	}
 
 	p->projects_list_menu_ui_id = id;
@@ -2315,13 +2316,12 @@ static GtkRadioActionEntry radio_entries[] = {
 static guint n_radio_entries = G_N_ELEMENTS (radio_entries);
 
 static void
-menu_item_selected_cb (GtkItem *item, GladeWindow *window)
+menu_item_selected_cb (GtkWidget *item, GladeWindow *window)
 {
 	GtkAction *action;
 	gchar *tooltip;
 
-	action = GTK_ACTION (g_object_get_data (G_OBJECT (item), "action-for-proxy"));
-
+        action = gtk_widget_get_action (item);
 	g_object_get (G_OBJECT (action), "tooltip", &tooltip, NULL);
 
 	if (tooltip != NULL)
@@ -2345,10 +2345,8 @@ ui_connect_proxy_cb (GtkUIManager *ui,
 		         GladeWindow *window)
 {	
 	if (GTK_IS_MENU_ITEM (proxy))
-	{	
-		g_object_set_data (G_OBJECT (proxy), "action-for-proxy", action);
-	
-		g_signal_connect(G_OBJECT(proxy), "select", 
+	{
+		g_signal_connect(G_OBJECT(proxy), "select",
 				 G_CALLBACK (menu_item_selected_cb), window);
 		g_signal_connect(G_OBJECT(proxy), "deselect", 
 				 G_CALLBACK (menu_item_deselected_cb), window);
@@ -2550,12 +2548,12 @@ add_project (GladeWindow *window, GladeProject *project)
  	
  	view = glade_design_view_new (project);	
 	gtk_widget_show (view);
-	
+
 	glade_app_add_project (project);
 
 	gtk_notebook_append_page (GTK_NOTEBOOK (window->priv->notebook), GTK_WIDGET (view), NULL);
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (window->priv->notebook), -1);	
-	
+		
 }
 
 void
@@ -3051,22 +3049,15 @@ glade_window_init (GladeWindow *window)
 	gtk_box_pack_start (GTK_BOX (vbox), priv->toolbar, FALSE, TRUE, 0);
 	gtk_widget_show (priv->toolbar);
 
-	/* tooltips object */
-	priv->tooltips =  gtk_tooltips_new ();
-
 	/* undo/redo buttons */
 	priv->undo = gtk_menu_tool_button_new_from_stock (GTK_STOCK_UNDO);
 	priv->redo = gtk_menu_tool_button_new_from_stock (GTK_STOCK_REDO);
 	gtk_widget_show (GTK_WIDGET (priv->undo));
 	gtk_widget_show (GTK_WIDGET (priv->redo));
-	gtk_menu_tool_button_set_arrow_tooltip (GTK_MENU_TOOL_BUTTON (priv->undo),
-						priv->tooltips,
-						_("Go back in undo history"),
-						NULL);
-	gtk_menu_tool_button_set_arrow_tooltip (GTK_MENU_TOOL_BUTTON (priv->redo),
-						priv->tooltips,
-						("Go forward in undo history"),
-						NULL); 
+	gtk_menu_tool_button_set_arrow_tooltip_text (GTK_MENU_TOOL_BUTTON (priv->undo),
+						     _("Go back in undo history"));
+	gtk_menu_tool_button_set_arrow_tooltip_text (GTK_MENU_TOOL_BUTTON (priv->redo),
+						     _("Go forward in undo history"));
 
 	sep = GTK_WIDGET (gtk_separator_tool_item_new ());
 	gtk_widget_show (sep);
@@ -3093,8 +3084,6 @@ glade_window_init (GladeWindow *window)
 	gtk_paned_pack1 (GTK_PANED (hpaned1), hpaned2, TRUE, FALSE);
 	gtk_paned_pack2 (GTK_PANED (hpaned1), vpaned, FALSE, FALSE);
 
-	/* divider position between design area and editor/inspector */
-	gtk_paned_set_position (GTK_PANED (hpaned1), 350);
 	/* divider position between tree and editor */	
 	gtk_paned_set_position (GTK_PANED (vpaned), 150);
 
@@ -3113,9 +3102,10 @@ glade_window_init (GladeWindow *window)
 	palette = GTK_WIDGET (glade_app_get_palette ());
 	glade_palette_set_show_selector_button (GLADE_PALETTE (palette), FALSE);
 	gtk_paned_pack1 (GTK_PANED (hpaned2), palette, FALSE, FALSE);
-	gtk_widget_show (palette);
 	setup_dock (&priv->docks[DOCK_PALETTE], palette, 200, 540, 
 		    _("Palette"), "palette", hpaned2, TRUE);
+	gtk_widget_set_size_request (palette, 200, 540);
+	gtk_widget_show (palette);
 
 	/* inspectors */
 	priv->inspectors_notebook = gtk_notebook_new ();	
